struct NoRcBlock {
why_blocked: &'static str,
}Expand description
Placeholder for the RC-block which will not allocate words.
The job of this struct is to prevent allocation of words in the RC-block while we are still trying to compute the origin of each block of the program.
Fields
why_blocked: &'static strTrait Implementations
Sourceimpl RcAllocator for NoRcBlock
impl RcAllocator for NoRcBlock
fn allocate( &mut self, _source: RcWordSource, _value: Unsigned36Bit, ) -> Result<Address, RcWordAllocationFailure>